@@ -59,7 +59,6 @@ class TextEditorWindow(Window):
 
     def dup(self):
         ret = self.__class__(parent=self.parent)
-        ret.show_doc(self.document)
         return ret
 
     def set_splitter(self, splitter):
@@ -69,7 +68,6 @@ class TextEditorWindow(Window):
         self.statusbar = statusbar
 
     def bring_top(self):
-        self._update_activeframe()
         if curses.panel.top_panel() is not self._panel:
             super().bring_top()
 
@@ -89,7 +87,7 @@ class TextEditorWindow(Window):
     def _update_activeframe(self):
         frame = self.get_label('frame')
         if frame:
-            self.mainframe.set_activeframe(frame)
+            frame.bring_top()
             frame.set_active_editor(self)
 
     def on_focus(self):
@@ -170,14 +168,16 @@ class TextEditorWindow(Window):
             lineno_color = self.document.mode.theme.get_style('lineno').cui_colorattr
             lineno_width = screen.calc_lineno_width(self.screen)
             lineno = self.document.buf.lineno.lineno(self.screen.pos)
-
+        
+        _, cursorrow = self.screen.getrow(self.cursor.pos)
         for n, row in enumerate(rows):
             if n > h:
                 break
             if drawn.get(row) == (n, cur_sel):
                 # The raw was already drawn.
                 continue
-
+            
+            is_cursorline = row is cursorrow
             updated = True
             s = 0
 
@@ -205,6 +205,9 @@ class TextEditorWindow(Window):
 
             rjust = False
             for (attr, attr_rjust), group in itertools.groupby(self._getcharattrs(row)):
+                if is_cursorline and self.document.mode.HIGHLIGHT_CURSORLINE:
+                    attr |= curses.A_BOLD
+                    
                 if not rjust and attr_rjust:
                     rjust = True
 
@@ -230,6 +233,9 @@ class TextEditorWindow(Window):
 
     def on_document_updated(self, pos, inslen, dellen):
         self.screen.on_document_updated(pos, inslen, dellen)
+        endpos = self.document.endpos()
+        if self.cursor.pos > endpos:
+            self.cursor.pos = endpos
 
     def style_updated(self, posfrom, posto):
         f, t = self.screen.get_visible_range()
