@@ -69,6 +69,7 @@ class FrameListCommands(Commands):
     @norec
     @norerun
     def close(self, wnd):
+        # bring the frame a top of frame list.
         if wnd.document.mode._activated_frame:
             wnd.mainframe.register_childframe(
                 wnd.document.mode._activated_frame)
@@ -136,6 +137,7 @@ class FrameListMode(dialogmode.DialogMode):
         return 0   # hide cursor
 
     def on_esc_pressed(self, wnd, event):
+        super().on_esc_pressed(wnd, event)
         self.framelist_commands.close(wnd)
 
     def on_str(self, wnd, s):
